%% Parameters

ROIs_for_RS = {'HGPM','HGAL','PT','PP','STGP','STGM','STGA','InsP','STSU','STSL','MTGP','MTGM','MTGA','SMG','AGA','AGP','IFGop','IFGtr','IFGor','MFG','SFG','ACC','OG','TFG','dPreCG','dPostCG','vPreCG','vPostCG','PMC','CingM','PCCpreCun','PHG','FG','ITGP','ITGM','ITGA','TP','InsA','fOperc','GR','SPL','LingG','MOG','Amyg','Hipp'};
threshold = 1/3; %2/5; %1/3; %2/5; %1/5;
base_t = 'multiscale';

%% ROI mapping
[ROI_table,ROImap] = ecogutils.loadROItable('ROI_table','GroupPCC');
fullROI_table = ROI_table;
avgROI_table = ROI_table(ismember(ROI_table.oldROI,ROIs_for_RS),:);

%% RS
ephysMeasures = {'envCorrDBTorth_gamma'};

%ephysMeasures = {'envCorrDBTorth_highGamma','envCorrDBTorth_gamma','envCorrDBTorth_beta','envCorrDBTorth_alpha','envCorrDBTorth_theta','wPLI_dbt_beta','wPLI_dbt_alpha','wPLI_dbt_theta'};
state = 'RS';

d = struct();
roiNSubj = nan(size(fullROI_table,1),1);
roiNSites = nan(size(fullROI_table,1),1);

for iMeas = 1:length(ephysMeasures)
    tic
    [allAdjMat,allSubj] = loadData(ephysMeasures{iMeas},fullROI_table,ROImap);


    if iMeas==1
        % Count used ROIs
        for iROI = 1:size(fullROI_table,1)
            roiNSubj(iROI) = sum(arrayfun(@(x) ismember(fullROI_table.oldROI{iROI},x.ROI), allAdjMat));
            roiNSites(iROI) = sum(arrayfun(@(x) sum(strcmp(x.ROI,fullROI_table.oldROI{iROI})), allAdjMat));
        end
    end

    allAdjMat.embed(threshold,'cosine',base_t);
    avgROIAdjMat = allAdjMat.avgByROI(ROIs_for_RS);

    avgSubjAdjMat = AdjMatrix(mean(cat(3,avgROIAdjMat.Adj),3,'omitNan'),struct('ROI',ROIs_for_RS));
    avgSubjEmb = avgSubjAdjMat.embed(threshold,'cosine',base_t);
    avgSubjEmb5 = avgSubjAdjMat.embed(threshold,'cosine',5);

    disp(ephysMeasures{iMeas});
    disp(avgSubjEmb.Elbow);



    rng(2023);
    [embedMn,embedSD,~,~,embedDistCorr,~,~,~,bootEmb] = bootstrapEmbedding(cat(3,avgROIAdjMat.Adj),100000,{threshold,'cosine',base_t});
    [embedMn5,embedSD5,~,~,~,~,~,~] = bootstrapEmbedding(cat(3,avgROIAdjMat.Adj),100000,{threshold,'cosine',5});



    %% Hennig - clusterwise stability measure

    nBoot = size(bootEmb,3);
    nItems = size(avgSubjEmb.Emb,1);
    nClustList = 2:(nItems-1);
    nClustN = length(nClustList);
    stability = cell(nClustN,1);
    nullstability = cell(nClustN,1);
    useDims = [2 avgSubjEmb.Elbow];

    allClustOut = cell(nClustN,1);
    for ik = 1:nClustN
        k = nClustList(ik);

        clustOut = RSDME.hierAgglomClust(avgSubjEmb.Emb,useDims,[],k);
        allClustOut{ik} = clustOut;
        thisStability = nan(k,nBoot);
        nullStability = nan(k,nBoot);
        parfor iBoot = 1:nBoot
            clustOutBoot = RSDME.hierAgglomClust(bootEmb(:,:,iBoot),useDims,[],k);
            clustOutNull = clustOutBoot(randperm(length(clustOutBoot)));
            % Calculate intersect/union for each pair
            jaccard = zeros(k);
            jaccardnull = zeros(k);
            for ii=1:k
                for jj=1:k
                    jaccard(ii,jj) = sum(clustOut==ii & clustOutBoot==jj)/sum(clustOut==ii | clustOutBoot==jj);
                    jaccardnull(ii,jj) = sum(clustOut==ii & clustOutNull==jj)/sum(clustOut==ii | clustOutNull==jj);
                end
            end

            % Find the "best" stability for each row
            js = max(jaccard,[],2);

            % Do the same thing for the scrambled "null" version
            jsnull = max(jaccardnull,[],2);

            %
            thisStability(:,iBoot) = js;
            nullStability(:,iBoot) = jsnull;
        end

        stability{ik} = mean(thisStability,2);
        nullstability{ik} = mean(nullStability,2);
    end

    %% Fowlkes and Mallows - overall stability measure

    nBoot = size(bootEmb,3);
    nItems = size(avgSubjEmb.Emb,1);
    nClustList = 2:(nItems-1);
    nClustN = length(nClustList);
    clustB = zeros(nClustN,nBoot);
    clustEB = zeros(nClustN,nBoot);
    useDims = [2 avgSubjEmb.Elbow];


        for iClust = 1:nClustN
            thisNClust = nClustList(iClust);
            clustOut = RSDME.hierAgglomClust(avgSubjEmb.Emb,useDims,[],thisNClust);
    
            parfor iBoot = 1:nBoot
                clustOutBoot = RSDME.hierAgglomClust(bootEmb(:,:,iBoot),useDims,[],thisNClust);
    
                M = crosstab(clustOut,clustOutBoot);
                T = sum(M.^2,'all') - nItems;
                P = sum(sum(M,1).^2) - nItems;
                Q = sum(sum(M,2).^2) - nItems;
    
                clustB(iClust,iBoot) = T/sqrt(P*Q);
                clustEB(iClust,iBoot) = sqrt(P*Q)/(nItems*(nItems-1));
            end
    
        end

    %%



    d.(ephysMeasures{iMeas}).allAdjMat = allAdjMat;
    d.(ephysMeasures{iMeas}).avgSubjAdjMat = avgSubjAdjMat;
    d.(ephysMeasures{iMeas}).avgSubjEmb = avgSubjEmb;
    d.(ephysMeasures{iMeas}).bootstrapMn = embedMn;
    d.(ephysMeasures{iMeas}).bootstrapSD = embedSD;
    d.(ephysMeasures{iMeas}).bootstrapDistanceCorrelation = embedDistCorr;
    d.(ephysMeasures{iMeas}).avgSubjEmb5 = avgSubjEmb5;
    d.(ephysMeasures{iMeas}).bootstrapMn5 = embedMn5;
    d.(ephysMeasures{iMeas}).bootstrapSD5 = embedSD5;
    d.(ephysMeasures{iMeas}).clustMembership = allClustOut;
    d.(ephysMeasures{iMeas}).clustNs = nClustList;
    d.(ephysMeasures{iMeas}).clustB = clustB;
    d.(ephysMeasures{iMeas}).clustEB = clustEB;

    d.(ephysMeasures{iMeas}).stability = stability;
    d.(ephysMeasures{iMeas}).nullstability = nullstability;
    toc
end

allROIs = ROI_table.oldROI;
usedROIs = ismember(allROIs,ROIs_for_RS);
d.coverageCountTable = table(allROIs,roiNSubj,roiNSites,usedROIs);

%% STSU vs STSL
% primaryMeasure = 'envCorrDBTorth_gamma';
d.STSAudTest = struct();
d.STSSemTest = struct();

for iMeas = 1:length(ephysMeasures)
    tic

    allAdjMat = loadData(ephysMeasures{iMeas},fullROI_table,ROImap);
    allAdjMat.embed(threshold,'cosine',base_t);
    avgROIAdjMat = allAdjMat.avgByROI(ROIs_for_RS);

    allAdjMat = cat(3,avgROIAdjMat.Adj);
    STSL_idx = find(strcmp(ROIs_for_RS,'STSL'),1,'first');
    STSU_idx = find(strcmp(ROIs_for_RS,'STSU'),1,'first');

    AuditoryROIs = ismember(ROIs_for_RS,{'HGPM','HGAL','PT','PP','STGP','STGM'});
    SemanticROIs = ismember(ROIs_for_RS,{'IFGop', 'IFGtr', 'IFGor', 'TP', 'STGA', 'MTGA', 'ITGA', 'MTGP', 'ITGP', 'AGA', 'AGP', 'SMG'});


    avgSubjAdjMat = AdjMatrix(mean(allAdjMat,3,'omitnan'),struct('ROI',ROIs_for_RS));
    avgSubjEmb = avgSubjAdjMat.embed(threshold,'cosine',base_t);
    embDist = avgSubjEmb.embDistUsingElbow();

    relDistToAud = mean(embDist(STSL_idx,AuditoryROIs)) - mean(embDist(STSU_idx,AuditoryROIs));
    relDistToSemantic = mean(embDist(STSL_idx,SemanticROIs)) - mean(embDist(STSU_idx,SemanticROIs));

    nPerm = 100000;
    permute_relDistToAud = nan(nPerm,1);
    permute_relDistToSem = nan(nPerm,1);
    parfor ii=1:nPerm
        thisAdjMat = RSDME.permuteROIpair(allAdjMat,STSL_idx,STSU_idx);
        avgSubjAdjMat = AdjMatrix(thisAdjMat,struct('ROI',ROIs_for_RS));
        avgSubjEmb = avgSubjAdjMat.embed(threshold,'cosine',base_t);

        embDist = avgSubjEmb.embDistUsingElbow();
        permute_relDistToAud(ii) = mean(embDist(STSL_idx,AuditoryROIs)) - mean(embDist(STSU_idx,AuditoryROIs));
        permute_relDistToSem(ii) = mean(embDist(STSL_idx,SemanticROIs)) - mean(embDist(STSU_idx,SemanticROIs));
    end

    d.STSAudTest.(ephysMeasures{iMeas}) = ['Distance to Auditory: ' reportPermuteTest(relDistToAud,permute_relDistToAud,'STSL','STSU')];
    d.STSSemTest.(ephysMeasures{iMeas}) = ['Distance to Semantic: ' reportPermuteTest(relDistToSemantic,permute_relDistToSem,'STSL','STSU')];

    toc
end

d.allSubj = allSubj;

if base_t == 1
    t_str = '';
elseif isnumeric(base_t)
    t_str = ['_t' num2str(base_t)];
else
    t_str = ['_t' base_t];
end

if threshold == 1/3
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdata' t_str '.mat'],'d','avgROI_table','fullROI_table');
elseif threshold == 1/10
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdatathresh10' t_str '.mat'],'d','avgROI_table','fullROI_table');
elseif threshold == 1/5
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdatathresh20' t_str '.mat'],'d','avgROI_table','fullROI_table');
elseif threshold == 2/5
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdatathresh40' t_str '.mat'],'d','avgROI_table','fullROI_table');
elseif threshold == 1/2
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdatathresh50' t_str '.mat'],'d','avgROI_table','fullROI_table');
elseif threshold == 1
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'RSdatathresh100' t_str '.mat'],'d','avgROI_table','fullROI_table');
end


function [out] = reportPermuteTest(val,dist,A,B)
out = [A ' - ' B ' = ' num2str(val,3) ', p = ' num2str(getP(val,dist))];
end

function [p] = getP(x,v)
p1 = sum(x>v)/(length(v)+1);
p2 = 1-sum(x<v)/(length(v)+1);
if p1>.5
    p = 1-p1;
else
    p = p2;
end
p = p*2;
end

