filePath = '\\ODIN\p\graham_preprocessing\importnat_data_from_graham\';

subjects = {'369','372','376','400','405','409','418','423','456','460'};

ROIsToUse = {'OG','PHG','STGM','TFG','PP','PT','ITGP','SPL','vPostCG','TP','IFGor','GR','ITGA','STGA','MOG','IFGop','PMC','STSL','STGP','SMG',...
    'dPreCG','CingM','MTGM','InsA','ITGM','vPreCG','MFG','dPostCG','ACC','AGP','MTGA','AGA','IFGtr','Hipp','MTGP','HGAL','FG','InsP','HGPM'};

threshold = 1/3;

ROI_table = ecogutils.loadROItable();
mapping = 'GroupPCC';
if ~isempty(mapping)
    ROImap = containers.Map(ROI_table.oldROI,ROI_table.(mapping));
    [~,useROItableRows] = unique(ROI_table.(mapping),'stable');
    ROI_table = ROI_table(useROItableRows,:);
    ROI_table.oldROI = ROI_table.(mapping);
end
fullROI_table = ROI_table;
ROI_table = ROI_table(ismember(ROI_table.oldROI,ROIsToUse),:);
nROI = size(ROI_table,1);


ephysMeasures = {'envCorrDBTorth_highGamma','envCorrDBTorth_gamma','envCorrDBTorth_beta','envCorrDBTorth_alpha','envCorrDBTorth_theta','wPLI_dbt_beta','wPLI_dbt_alpha','wPLI_dbt_theta'};
adjMatByElectrode = struct();
ephysByROI = struct();
fmriByROI = struct();
for iMeas = 1:length(ephysMeasures)
    [adjMatByElectrode.(ephysMeasures{iMeas}),ephysByROI.(ephysMeasures{iMeas}),fmriByROI,coverageCountTable] = ROIAvgEphys(subjects,ephysMeasures{iMeas},ROImap,fullROI_table,'RS');

    % Limit to only ROIs used across subjects
    keepROIs = ismember(fullROI_table.oldROI,ROIsToUse);
    ephysByROI.(ephysMeasures{iMeas}) = ephysByROI.(ephysMeasures{iMeas})(keepROIs,keepROIs,:);
end
fmriByROI = fmriByROI(keepROIs,keepROIs,:);

fMRIAvgEmbedding = Embedding(mean(fmriByROI,3,'omitnan'),floor(nROI*threshold),'cosine');
ephysAvgEmbedding = Embedding(mean(ephysByROI.envCorrDBTorth_gamma,3,'omitnan'),floor(nROI*threshold),'cosine');

figure()
hold on;
plot(fMRIAvgEmbedding.EigenValues(2:end),'o')
plot(ephysAvgEmbedding.EigenValues(2:end),'o')
plot(fMRIAvgEmbedding.Elbow-1,fMRIAvgEmbedding.EigenValues(fMRIAvgEmbedding.Elbow),'kx');
plot(ephysAvgEmbedding.Elbow-1,ephysAvgEmbedding.EigenValues(ephysAvgEmbedding.Elbow),'kx');
legend({'fMRI','Ephys'})

max(fMRIAvgEmbedding.Elbow,ephysAvgEmbedding.Elbow)

fmriDist = embDistUsingElbow(fMRIAvgEmbedding,5);
fmriDist = fmriDist(logical(triu(ones(size(fmriDist)),1)));
ephysDist = embDistUsingElbow(ephysAvgEmbedding,5);
ephysDist = ephysDist(logical(triu(ones(size(ephysDist)),1)));

% For Fig7a&b
[remappedEphysAvgEmbedding] = ephysAvgEmbedding.map(fMRIAvgEmbedding);


avgCorr = zeros(length(ephysMeasures),1);
subjCorr = zeros(length(ephysMeasures),length(subjects));
for iMeas = 1:length(ephysMeasures)
    ephysAvgEmbedding = Embedding(mean(ephysByROI.(ephysMeasures{iMeas}),3,'omitnan'),floor(nROI*threshold),'cosine');
    avgCorr(iMeas) = correlateEmbDistance(fMRIAvgEmbedding,ephysAvgEmbedding,5);
end

for iSubj = 1:length(subjects)
    nCh = length(adjMatByElectrode.(ephysMeasures{1}).fmri{iSubj});
    fmriIndivEmb = Embedding(adjMatByElectrode.(ephysMeasures{1}).fmri{iSubj},floor(nCh*threshold),'cosine');
    for iMeas = 1:length(ephysMeasures)
        ephysIndivEmb = Embedding(adjMatByElectrode.(ephysMeasures{iMeas}).ephys{iSubj},floor(nCh*threshold),'cosine');
        subjCorr(iMeas,iSubj) = correlateEmbDistance(fmriIndivEmb,ephysIndivEmb,max(fmriIndivEmb.Elbow,ephysIndivEmb.Elbow));


        if iMeas==2
            figure()
            title(subjects{iSubj})
            hold on;
            plot(fmriIndivEmb.EigenValues(2:end),'o')
            plot(ephysIndivEmb.EigenValues(2:end),'o')
            plot(fmriIndivEmb.Elbow-1,fmriIndivEmb.EigenValues(fmriIndivEmb.Elbow),'kx');
            plot(ephysIndivEmb.Elbow-1,ephysIndivEmb.EigenValues(ephysIndivEmb.Elbow),'kx');
            legend({'fMRI','Ephys'})
        end
    end
end

fMRIAvgEmb = fMRIAvgEmbedding.Emb;
ROInames = ROI_table.oldROI;
ROIcolors = [ROI_table.colorR ROI_table.colorG ROI_table.colorB];

coverageCountTable.usedROIs = ismember(coverageCountTable.allROIs,ROIsToUse);

fmriephysfig = struct('ephysMeasures',{ephysMeasures},'ephysMeasureNames',{{'HighGamma','Gamma','Beta','Alpha','Theta'}},'subjects',{subjects},'avgCorr',avgCorr,'subjCorr',subjCorr,'fMRIAvgEmb',fMRIAvgEmb,'remappedEphysAvgEmbedding',remappedEphysAvgEmbedding,'fmriDist',fmriDist,'ephysDist',ephysDist,'ROInames',{ROInames},'ROIcolors',ROIcolors,'coverageCountTable',coverageCountTable);
save([getLocalPath('ECoGoutput') 'DMEsummaries' filesep 'fmriEphysComparisonData.mat'],'-struct','fmriephysfig');


% Electrode-related embeddings: per subject and average, plus associated
% iEEG embeddings

% Pairwise distances from these embeddings

% Full fMRI, partial fMRI, partial fMRI by electrode


Full_fMRI = cell(length(subjects),1);
Partial_fMRI = cell(length(subjects),1);
SiteLevel_fMRI = cell(length(subjects),1);
Full_fMRI_IDs = cell(length(subjects),1);
Partial_fMRI_IDs = cell(length(subjects),1);
SiteLevel_fMRI_IDs = cell(length(subjects),1);
for iSubj = 1:length(subjects)
    disp(subjects{iSubj})

    thisFile = [filePath subjects{iSubj} filesep 'schaefer7' filesep subjects{iSubj} '_pearson_corr_roi_selected_full.xlsx'];
    d = readcell(thisFile);
    rowNames = d(2:end,1);
    pearson = cell2mat(d(2:end,2:end));
    pearson = (pearson+pearson')/2;
    Full_fMRI_IDs{iSubj} = [rowNames{:}];
    Full_fMRI{iSubj} = pearson;


    thisFile = [filePath subjects{iSubj} filesep 'schaefer7' filesep subjects{iSubj} '_pearson_corr_roi_selected_roi_averaged.xlsx'];
    d = readcell(thisFile);
    rowNames = d(2:end,1);
    pearson = cell2mat(d(2:end,2:end));
    pearson = (pearson+pearson')/2;
    Partial_fMRI_IDs{iSubj} = [rowNames{:}];
    Partial_fMRI{iSubj} = pearson;


    thisFile = [filePath subjects{iSubj} filesep 'schaefer7' filesep subjects{iSubj} '_pearson_corr_electrode_selected_electrode_averaged.xlsx'];
    d = readcell(thisFile);
    rowNames = d(2:end,1);
    pearson = cell2mat(d(2:end,2:end));
    pearson = (pearson+pearson')/2;
    SiteLevel_fMRI_IDs{iSubj} = [rowNames{:}];
    SiteLevel_fMRI{iSubj} = pearson;

    %
    %
    %     ROI(~ismember(ROI,ROI_table.oldROI))
    %
    %     for iROI=1:nROI
    %         i_idx = find(strcmp(ROI,ROI_table.oldROI{iROI}),1,'first');
    %         if ~isempty(i_idx)
    %             for jROI=iROI:nROI
    %                 j_idx = find(strcmp(ROI,ROI_table.oldROI{jROI}),1,'first');
    %                 if ~isempty(j_idx)
    %                     ER_fMRI(iROI,jROI,iSubj) = pearson(i_idx,j_idx);
    %                     ER_fMRI(jROI,iROI,iSubj) = ER_fMRI(iROI,jROI,iSubj);
    %                 end
    %             end
    %         end
    %     end
end



fullvpartial = nan(length(subjects),1);
sitevROI = nan(length(subjects),1);
for iSubj=1:length(subjects)
    fullEmbed = Embedding(Full_fMRI{iSubj},floor(length(Full_fMRI{iSubj})*threshold),'cosine');
    fullEmb = fullEmbed.Emb;
    subsetFullEmb = fullEmb(ismember(Full_fMRI_IDs{iSubj},Partial_fMRI_IDs{iSubj}),:);
    partialEmbed = Embedding(Partial_fMRI{iSubj},floor(length(Partial_fMRI{iSubj})*threshold),'cosine');
    sitelevelEmbed = Embedding(SiteLevel_fMRI{iSubj},floor(length(SiteLevel_fMRI{iSubj})*threshold),'cosine');
    sitelevelEmbBasisChanged = sitelevelEmbed.map(partialEmbed);

    fullvpartial(iSubj) = correlateEmbDistance(subsetFullEmb,partialEmbed.Emb,5);
    sitevROI(iSubj) = correlateEmbDistance(sitelevelEmbBasisChanged,partialEmbed.Emb,5);
end

colorInfo = load('Q:\Ephys\AnalysisOutput\FmriEegComps\376_f-avgROI_vs_er-avgROI_gamma_schaefer7.mat');
exSubj = 3;
fullEmbed = Embedding(Full_fMRI{exSubj},floor(length(Full_fMRI{exSubj})*threshold),'cosine');
fullEmb = fullEmbed.Emb;
subsetFullEmb = fullEmb(ismember(Full_fMRI_IDs{exSubj},Partial_fMRI_IDs{exSubj}),:);
partialEmbed = Embedding(Partial_fMRI{exSubj},floor(length(Partial_fMRI{exSubj})*threshold),'cosine');
partialEmb = partialEmbed.Emb;
sitelevelEmbed = Embedding(SiteLevel_fMRI{exSubj},floor(length(SiteLevel_fMRI{exSubj})*threshold),'cosine');
sitelevelEmbBasisChanged = sitelevelEmbed.map(partialEmbed);


fullColors = colorInfo.fullColors;
otherColors = colorInfo.erColors;


fullDist = embDistUsingElbow(fullEmbed);
fullDist = fullDist(ismember(Full_fMRI_IDs{exSubj},Partial_fMRI_IDs{exSubj}),ismember(Full_fMRI_IDs{exSubj},Partial_fMRI_IDs{exSubj}));
fullDist = fullDist(logical(triu(ones(size(fullDist)),1)));
partialDist = embDistUsingElbow(partialEmbed);
partialDist = partialDist(logical(triu(ones(size(partialDist)),1)));


save([getLocalPath('ECoGoutput') 'DMEsummaries' filesep 'fmriCoverageBias.mat'],'exSubj','fullvpartial','sitevROI','fullEmb','subsetFullEmb','partialEmb','sitelevelEmbBasisChanged','fullColors','otherColors','fullDist','partialDist');





function [r] = correlateEmbDistance(e1,e2,maxDim)

if isa(e1,'Embedding')
    d1 = embDistUsingElbow(e1,maxDim);
    d2 = embDistUsingElbow(e2,maxDim);
else
    nodes = size(e1,1);
    d1 = zeros(nodes);
    d2 = zeros(nodes);
    for ii=1:nodes
        for jj=ii:nodes
            d1(ii,jj) = norm(e1(ii,2:maxDim) - e1(jj,2:maxDim));
            d1(jj,ii) = d1(ii,jj);
            d2(ii,jj) = norm(e2(ii,2:maxDim) - e2(jj,2:maxDim));
            d2(jj,ii) = d2(ii,jj);
        end
    end
end
d1 = d1(logical(triu(ones(size(d1)),1)));
d2 = d2(logical(triu(ones(size(d2)),1)));
r = corr(d1,d2);

end

function [adjMatByElectrode,ephysByROI,fmriByROI,coverageCountTable] = ROIAvgEphys(subjects,measure,ROImap,ROI_table,state)

filepath = [getLocalPath('ECoGoutput') 'MeanConn' filesep 'RS - ' measure '-earlySVD.mat'];
nROI = size(ROI_table,1);
thisM = ['mean_' measure];

d = load(filepath);
if ~istable(d.dataTable)
    d.dataTable = struct2table(d.dataTable);
end



d.dataTable = d.dataTable(contains(d.dataTable.patientID,subjects),:);

ephysByROI = nan(nROI,nROI,size(d.dataTable,1));
fmriByROI = nan(nROI,nROI,size(d.dataTable,1));
ephys = cell(size(d.dataTable,1),1);
fmri = cell(size(d.dataTable,1),1);
contactNumbers = cell(size(d.dataTable,1),1);

roiNSubj = nan(size(ROI_table,1),size(d.dataTable,1));
roiNSites = nan(size(ROI_table,1),size(d.dataTable,1));

for iSubj = 1:size(d.dataTable,1)
    thisSubj = d.dataTable.patientID{iSubj};
    disp(thisSubj)

    theseChannels = d.dataTable.ECoGchannels{iSubj};
    theseChannels = mapChannels(theseChannels,ROImap);
    ephysAdj = d.dataTable.(thisM){iSubj}.(state);
    % Set diagonals of chan x chan to 1
    ephysAdj(logical(eye(length(ephysAdj)))) = 1;


    thisFile = ['\\ODIN\p\graham_preprocessing\importnat_data_from_graham\' thisSubj(1:3) filesep 'banks' filesep thisSubj(1:3) '_pearson_corr_electrode_full_eeg_selected.xlsx'];
    d2 = readcell(thisFile);
    chNames = d2(2:end,1);
    pearson = cell2mat(d2(2:end,2:end));
    pearson = (pearson+pearson')/2;


    % Contact numbers from each
    contactNumbersFMRI = [chNames{:}];
    contactNumbersEEG = [theseChannels.contNum]';


    % Select intersecting contact numbers
    [~,ia,ib] = intersect(contactNumbersFMRI,contactNumbersEEG);

    pearson = pearson(ia,ia);

    theseChannels = theseChannels(ib);
    ephysAdj = ephysAdj(ib,ib);


    roiNSites(:,iSubj) = arrayfun(@(x) sum(strcmp({theseChannels.oldROI},x)), ROI_table.oldROI);
    roiNSubj(:,iSubj) = roiNSites(:,iSubj)>0;


    % Get sort order
    [sortIndex,~,~,secondSort] = ecogutils.chanSort(theseChannels,ROI_table,'','');

    ephysAdj = ephysAdj(sortIndex,sortIndex);
    pearson = pearson(sortIndex,sortIndex);


    % Assign electrode-by-electrode adj mat
    ephys{iSubj} = ephysAdj;
    fmri{iSubj} = pearson;
    contactNumbers{iSubj} = [theseChannels(sortIndex).contNum]';

    for ii=1:nROI
        for jj=ii:nROI
            ephysByROI(ii,jj,iSubj) = mean(ephysAdj(secondSort==ii,secondSort==jj),'all');
            ephysByROI(jj,ii,iSubj) = ephysByROI(ii,jj,iSubj);

            fmriByROI(ii,jj,iSubj) = mean(pearson(secondSort==ii,secondSort==jj),'all');
            fmriByROI(jj,ii,iSubj) = fmriByROI(ii,jj,iSubj);
        end
    end
end
adjMatByElectrode = table(contactNumbers,ephys,fmri);

roiNSubj = sum(roiNSubj,2);
roiNSites = sum(roiNSites,2);
allROIs = ROI_table.oldROI;
usedROIs = false(size(allROIs));
coverageCountTable = table(allROIs,roiNSubj,roiNSites,usedROIs);

end

function [chans] = mapChannels(chans,ROImap)
oldROIs = {chans.oldROI};
oldROIs(isKey(ROImap,oldROIs)) = values(ROImap,oldROIs(isKey(ROImap,oldROIs)));
[chans.oldROI] = oldROIs{:};
end

function [x,keepRows] = stripNaN(x)
keepRows = ~all(isnan(x),1);
x = x(keepRows,keepRows);
end