%% Parameters

ROIs_for_Dom = {'HGPM','HGAL','PT','PP','STGP','STGM','STGA','InsP','STSL','MTGP','MTGM','MTGA','SMG','AGA','IFGop','IFGtr','IFGor','MFG','OG',...
    'dPreCG','vPreCG','vPostCG','PMC','PHG','FG','ITGP','ITGM','ITGA','TP','InsA','GR','Amyg','Hipp'};
measure = 'envCorrDBTorth_gamma';

threshold = 1/3;

%% ROI mapping
[ROI_table,ROImap] = ecogutils.loadROItable('ROI_table','GroupPCC');
fullROI_table = ROI_table;
avgROI_table = ROI_table(ismember(ROI_table.oldROI,ROIs_for_Dom),:);

%% Dom vs non-dom hemisphere

datasetdom = readtable([getLocalPath('ECoGmeta') 'dataset' filesep 'RSdom.xlsx']);
datasetnondom = readtable([getLocalPath('ECoGmeta') 'dataset' filesep 'RSnondom.xlsx']);
domSubjs = unique(datasetdom.patientID);
nondomSubjs = unique(datasetnondom.patientID);
% domSubjs = domSubjs(1:end-2);
% nondomSubjs = nondomSubjs(1:end-1);
bothSubjs = cat(1,domSubjs,nondomSubjs);
domLogic = false(size(bothSubjs));
domLogic(1:length(domSubjs)) = true;

bothAdjMat = loadData(measure,fullROI_table,ROImap,bothSubjs);

roiNSubj = nan(size(fullROI_table,1),1);
roiNSites = nan(size(fullROI_table,1),1);

% Count used ROIs
for iROI = 1:size(fullROI_table,1)
    roiNSubj(iROI) = sum(arrayfun(@(x) ismember(fullROI_table.oldROI{iROI},x.ROI), bothAdjMat));
    roiNSites(iROI) = sum(arrayfun(@(x) sum(strcmp(x.ROI,fullROI_table.oldROI{iROI})), bothAdjMat));
end

LanguageROIs = {'PT','PP','STSL','STGP','STGM','STGA','SMG','AGA','PMC','vPreCG','IFGop','IFGtr'};
idxLanguageROIs = ismember(ROIs_for_Dom,LanguageROIs);
langConnLogic = false(length(ROIs_for_Dom));
langConnLogic(idxLanguageROIs,idxLanguageROIs) = true;
langConnLogic = ecogutils.triuToVec(langConnLogic);

avgROIboth = bothAdjMat.avgByROI(ROIs_for_Dom);

avgSubjDom = AdjMatrix(mean(cat(3,avgROIboth(domLogic).Adj),3,'omitNan'),struct('ROI',ROIs_for_Dom));
avgSubjNondom = AdjMatrix(mean(cat(3,avgROIboth(~domLogic).Adj),3,'omitNan'),struct('ROI',ROIs_for_Dom));
avgSubjBoth = AdjMatrix(mean(cat(3,avgROIboth.Adj),3,'omitNan'),struct('ROI',ROIs_for_Dom));

avgSubjDom.embed(threshold,'cosine');
avgSubjNondom.embed(threshold,'cosine');
avgSubjBoth.embed(threshold,'cosine');

domMapped = avgSubjDom.Emb.map(avgSubjBoth.Emb);
nondomMapped = avgSubjNondom.Emb.map(avgSubjBoth.Emb);

% Difference between dom/nondom of average distance to center
meanCenterDistDiff = mean(vecnorm(avgSubjDom.Emb.Emb(:,2:avgSubjDom.Emb.Elbow),2,2)) - mean(vecnorm(avgSubjNondom.Emb.Emb(:,2:avgSubjNondom.Emb.Elbow),2,2));
% Contrast for language
meanCenterDistDiffLang = (mean(vecnorm(avgSubjDom.Emb.Emb(idxLanguageROIs,2:avgSubjDom.Emb.Elbow),2,2)) - mean(vecnorm(avgSubjNondom.Emb.Emb(idxLanguageROIs,2:avgSubjNondom.Emb.Elbow),2,2))) - ...
        (mean(vecnorm(avgSubjDom.Emb.Emb(~idxLanguageROIs,2:avgSubjDom.Emb.Elbow),2,2)) - mean(vecnorm(avgSubjNondom.Emb.Emb(~idxLanguageROIs,2:avgSubjNondom.Emb.Elbow),2,2)));

% Correlation of embedding distances for dom and non-dom hemisphere
embedDistCorrDomNondom = corr(ecogutils.triuToVec(avgSubjDom.Emb.embDistUsingElbow),ecogutils.triuToVec(avgSubjNondom.Emb.embDistUsingElbow));



%% Permute language dominance
nPerm = 100000;
nROI = length(ROIs_for_Dom);

embDistDiff = avgSubjDom.Emb.embDistUsingElbow() - avgSubjNondom.Emb.embDistUsingElbow();

selfDistance = nan(nROI,1);
for iROI = 1:nROI
    selfDistance(iROI) = pdist(cat(1,domMapped(iROI,2:avgSubjBoth.Emb.Elbow),nondomMapped(iROI,2:avgSubjBoth.Emb.Elbow)));
end



permEmbDistDiff = nan(nROI,nROI,nPerm);
permMappedSelfDistance = nan(nROI,nPerm);
permMeanDistance = nan(1,nPerm);
permLanguageDistDiff = nan(1,nPerm);
permMeanCenterDistDiff = nan(1,nPerm);
permMeanCenterDistDiffLang = nan(1,nPerm);
tic
parfor ii = 1:nPerm
    while (true)
    permLogic = domLogic(randperm(length(domLogic))); %#ok<PFBNS> 
    domPerm = AdjMatrix(mean(cat(3,avgROIboth(permLogic).Adj),3,'omitNan'),struct('ROI',ROIs_for_Dom)); %#ok<PFBNS> 
    nondomPerm = AdjMatrix(mean(cat(3,avgROIboth(~permLogic).Adj),3,'omitNan'),struct('ROI',ROIs_for_Dom));
        if ~any(isnan(domPerm.Adj),'all') && ~any(isnan(nondomPerm.Adj),'all')
            break;
        end
    end
    domPerm.embed(threshold,'cosine');
    nondomPerm.embed(threshold,'cosine');
    permEmbDistDiff(:,:,ii) = domPerm.Emb.embDistUsingElbow() - nondomPerm.Emb.embDistUsingElbow();
    distVec = ecogutils.triuToVec(permEmbDistDiff(:,:,ii));
    permMeanDistance(ii) = mean(distVec);
    permMeanCenterDistDiff(ii) = mean(vecnorm(domPerm.Emb.Emb(:,2:domPerm.Emb.Elbow),2,2)) - mean(vecnorm(nondomPerm.Emb.Emb(:,2:nondomPerm.Emb.Elbow),2,2));
    permMeanCenterDistDiffLang(ii) = (mean(vecnorm(domPerm.Emb.Emb(idxLanguageROIs,2:domPerm.Emb.Elbow),2,2)) - mean(vecnorm(nondomPerm.Emb.Emb(idxLanguageROIs,2:nondomPerm.Emb.Elbow),2,2))) - ...
        (mean(vecnorm(domPerm.Emb.Emb(~idxLanguageROIs,2:domPerm.Emb.Elbow),2,2)) - mean(vecnorm(nondomPerm.Emb.Emb(~idxLanguageROIs,2:nondomPerm.Emb.Elbow),2,2)));
    permLanguageDistDiff(ii) = mean(distVec(langConnLogic)) - mean(distVec(~langConnLogic));
    permDomMapped = domPerm.Emb.map(avgSubjBoth.Emb); %#ok<PFBNS> 
    permNondomMapped = nondomPerm.Emb.map(avgSubjBoth.Emb);
    for iROI = 1:nROI
        permMappedSelfDistance(iROI,ii) = pdist(cat(1,permDomMapped(iROI,2:avgSubjBoth.Emb.Elbow),permNondomMapped(iROI,2:avgSubjBoth.Emb.Elbow)));
    end
end
toc


%% ROI position test
pvalsSelfDistance = nan(nROI,1);
for iROI = 1:nROI
    pvalsSelfDistance(iROI) = getP(selfDistance(iROI),permMappedSelfDistance(iROI,:));
end


%% Distance edges test
relEmbDistDiff = embDistDiff-mean(ecogutils.triuToVec(embDistDiff));
pvalsEdges = nan(nROI,nROI);
for iROI = 1:nROI
    for jROI = 1:nROI
        if iROI~=jROI
            pvalsEdges(iROI,jROI) = getP(relEmbDistDiff(iROI,jROI),permEmbDistDiff(iROI,jROI,:)-reshape(permMeanDistance,[1 1 length(permMeanDistance)]));
        end
    end
end


%% Mean distance test
distVec = ecogutils.triuToVec(embDistDiff);
pvalsDistMean = getP(mean(distVec),permMeanDistance);


%% Mean distance language difference
pvalsLangDist = getP(mean(distVec(langConnLogic)) - mean(distVec(~langConnLogic)),permLanguageDistDiff);

%% Mean distance to center difference
pvalsCenterDistDiff = getP(meanCenterDistDiff,permMeanCenterDistDiff);
pvalsCenterDistDiffLang = getP(meanCenterDistDiffLang,permMeanCenterDistDiffLang);


%% Save

langDom = struct();
langDom.pvalsSelfDistance = pvalsSelfDistance;
[~,~,~,langDom.pvalsSelfDistanceFDR] = ecogutils.fdr_bh.fdr_bh(pvalsSelfDistance,0.05,'pdep');
langDom.pvalsEdges = pvalsEdges;
[~,~,~,langDom.pvalsEdgesFDR] = ecogutils.fdr_bh.fdr_bh(pvalsEdges,0.05,'pdep');
langDom.pvalsDistMean = pvalsDistMean;
langDom.pvalsLangDist = pvalsLangDist;
langDom.pvalsCenterDistDiff = pvalsCenterDistDiff;
langDom.pvalsCenterDistDiffLang = pvalsCenterDistDiffLang;
langDom.domMapped = domMapped;
langDom.nondomMapped = nondomMapped;
langDom.bothEmb = avgSubjBoth.Emb.Emb;

domDist = ecogutils.triuToVec(avgSubjDom.Emb.embDistUsingElbow());
nondomDist = ecogutils.triuToVec(avgSubjNondom.Emb.embDistUsingElbow());
langDom.domDistLang = domDist(langConnLogic);
langDom.domDistNonLang = domDist(~langConnLogic);
langDom.nondomDistLang = nondomDist(langConnLogic);
langDom.nondomDistNonLang = nondomDist(~langConnLogic);
langDom.domDistAll = domDist;
langDom.nondomDistAll = nondomDist;

langDom.ROIs = ROIs_for_Dom;
langDom.LanguageROIs = LanguageROIs;


allROIs = fullROI_table.oldROI;
usedROIs = ismember(allROIs,ROIs_for_Dom);
langDom.coverageCountTable = table(allROIs,roiNSubj,roiNSites,usedROIs);

if strcmp(measure,'envCorrDBTorth_gamma')
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'LangDom.mat'],'langDom','avgROI_table');
else
    save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'LangDom_' measure '.mat'],'langDom','avgROI_table');
end


function [p] = getP(x,v)
p1 = sum(x>v)/(length(v)+1);
p2 = 1-sum(x<v)/(length(v)+1);
if p1>.5
    p = 1-p1;
else
    p = p2;
end
p = p*2;
end
