function [adjMatSNR,embDistSNR] = segmentSNR(measure,DataSet,varargin)
%compareSNR Compare variation across vs within over time
%   For optional arguments, see '+ecogutils/postHocOptionsParser.m' and the
%   help for +patientSummaries/stateAverage.m
%
threshold = 1/3;

o = ecogutils.postHocOptionsParser(measure,DataSet,varargin{:});
if ~iscell(o.DataSet), o.DataSet = {o.DataSet}; end

ROI_table = ecogutils.loadROItable();


%% Load data and map states
[dataTable] = loadECoG.loadGoodData(o);

[patientList,ia,ib] = unique(dataTable.patientID,'stable');

nSubj = length(patientList);

allAdjMat(1:nSubj) = AdjMatrix;

for iSubj = 1:nSubj
    patientRows = ib==iSubj;
    allSegs = loadECoG.extractAdjMat(dataTable,o.measure,patientRows);
    % Set diagonals of chan x chan to 1
    allSegs(repmat(logical(eye(size(allSegs,1))),[1,1,size(allSegs,3)])) = 1;

    allAdjMat(iSubj) = AdjMatrix(allSegs,dataTable.ECoGchannels{ia(iSubj)});
end
allAdjMat.sortByROI(ROI_table);
allAdjMat.embed(threshold,'cosine');

adjMatSNR = arrayfun(@(x) calcSNR(x.Adj),allAdjMat);

embDistSNR = arrayfun(@(x) calcSNR(embDistUsingElbow(x.Emb)),allAdjMat);


h = figure('Position',[65 158 1485 792],'Name',measure);

scatter(adjMatSNR,embDistSNR,'k');

a = gca;
a.XScale = 'log';
a.YScale = 'log';
axis equal
xlabel('Adjacency Matrix Mean(SD(Mean)/SD)')
ylabel('Embedding Distance Mean(SD(Mean)/SD)')


% xlim([0 max([adjMatSNR embDistSNR])*1.1]);
% ylim([0 max([adjMatSNR embDistSNR])*1.1]);
refline(1,0);
title(measure)


%% Output

if isempty(o.OptionSet)
    optionString = '';
else
    optionString = ['-' o.OptionSet];
end

save([getLocalPath('ECoGoutput') 'Embeddings' filesep 'SNR ' o.measure optionString '.mat'],'adjMatSNR','embDistSNR');


end

function SNR = calcSNR(m)
u = zeros(((size(m,1)-1)*size(m,2))/2, size(m,3));
for ii=1:size(m,3)
    u(:,ii) = ecogutils.triuToVec(m(:,:,ii));
end
signal = std(mean(u,2));
noise = mean(std(u,[],2));
SNR = signal/noise;
end
