function [sortIndex,newROICount,firstSort,secondSortID] = chanSort(ECoGchannels,ROI_table,majorROI,minorROI,suppressWarning)
% Sort ECoGchannels by major and minor ROIs

%% Default is to sort first by newROINum, second by oldROINum
if nargin<3 || isempty(majorROI)
	majorROI = 'newROINum';
end
if nargin<4 || isempty(minorROI)
	minorROI = 'oldROINum';
end
if nargin<5
    suppressWarning = false;
end

oldROIs = {ECoGchannels.oldROI};


%% Compare oldROIs to ROI_table to get first and second sort conditions
firstSort = zeros(length(oldROIs),1)-1;
secondSort = zeros(length(oldROIs),1)-1;
secondSortID = zeros(length(oldROIs),1)-1;

for iROI = 1:size(ROI_table,1)
    firstSort(ismember(oldROIs,ROI_table.oldROI{iROI})) = ROI_table.(majorROI)(iROI);
    secondSort(ismember(oldROIs,ROI_table.oldROI{iROI})) = ROI_table.(minorROI)(iROI);
    secondSortID(ismember(oldROIs,ROI_table.oldROI{iROI})) = iROI;
end

%% Final sort condition is distance from the middle of HGPM, if available

if isfield(ECoGchannels,'MNIX') && isfield(ECoGchannels,'MNIY') && isfield(ECoGchannels,'MNIZ')
    if ischar([ECoGchannels.MNIX])
        xCoord = str2double({ECoGchannels.MNIX});
    else
        xCoord = [ECoGchannels.MNIX];
    end
    if ischar([ECoGchannels.MNIY])
        yCoord = str2double({ECoGchannels.MNIY});
    else
        yCoord = [ECoGchannels.MNIY];
    end
    if ischar([ECoGchannels.MNIZ])
        zCoord = str2double({ECoGchannels.MNIZ});
    else
        zCoord = [ECoGchannels.MNIZ];
    end
else
    xCoord = [ECoGchannels.xCoord];
    yCoord = [ECoGchannels.yCoord];
    zCoord = [ECoGchannels.zCoord];    
end
HGPMchans = strcmp(oldROIs,'HGPM');
HGPMXPos = mean(xCoord(HGPMchans));
HGPMYPos = mean(yCoord(HGPMchans));
HGPMZPos = mean(zCoord(HGPMchans));

if strcmp(majorROI,'newROINum')
    thirdSort = ((xCoord-HGPMXPos).^2 + (yCoord-HGPMYPos).^2 + (zCoord-HGPMZPos).^2).^0.5;
else
    thirdSort = yCoord;
end
thirdSort(isnan(thirdSort)) = 1000000;


%% Do the sort
[~,sortIndex] = sortrows([firstSort secondSort thirdSort']);

%% Exclude ROIs that have -1 for sortIndex (or are not in ROI_table)
notInROITable = find(secondSort==-1);
for ii = 1:length(notInROITable)
    if ~strcmp(oldROIs{notInROITable(ii)},'SZ') && ~strcmp(oldROIs{notInROITable(ii)},'WM')
        if ~suppressWarning
            disp([oldROIs{notInROITable(ii)} ' not in ROI_table'])
        end
    end
end

firstSort = firstSort(sortIndex);
secondSort = secondSort(sortIndex);
secondSortID = secondSortID(sortIndex);

keepIndices = firstSort~=-1 & secondSort~=-1 & ~isnan(firstSort) & ~isnan(secondSort);
sortIndex = sortIndex(keepIndices);
firstSort = firstSort(keepIndices);
secondSort = secondSort(keepIndices);
secondSortID = secondSortID(keepIndices);


%% Count numbers in majorROIs 
newROICount = zeros(max(unique(ROI_table.(majorROI))),1);

for iROI = 1:length(newROICount)
    newROICount(iROI) = sum(firstSort==iROI);
end
    