function [dataTable] = loadFileList(varargin)
%loadFileList Load and combine tables from multiple output files
%   Will include only columns found in all datasets, and adds a column
%   naming the originating data set

o = ecogutils.postHocOptionsParser(varargin{:});

dataPath = [getLocalPath('ECoGoutput') 'initial' filesep];

if ~iscell(o.DataSet), o.DataSet = {o.DataSet}; end

if isempty(o.OptionSet)
    optionString = '';
else
    optionString = ['-' o.OptionSet];
end

for iFile = 1:length(o.DataSet)
    dataset = char(o.DataSet{iFile});
    
    % Load dataset xls
    datasetxls = readtable([getLocalPath('ECoGmeta') 'dataset' filesep dataset '.xlsx']);
    
    % Load and concatenate relevant files
    data=cell(size(datasetxls,1),1);
    for iRow = 1:size(datasetxls,1)
        filename = [dataPath datasetxls.patientID{iRow} filesep datasetxls.patientID{iRow} '_' datasetxls.block{iRow} ' ' o.measure optionString '.mat'];
        thisFile = load(filename);
        data{iRow} = thisFile.out;
        if ismember('rejectSummary',data{iRow}.Properties.VariableNames)
            data{iRow} = removevars(data{iRow},'rejectSummary');
        end
    end
    try
        data = cat(1,data{:});
    catch ME
        error('Data tables may be from incompatible versions of the analysis software. Try re-running analysis with the latest version.');
        rethrow(ME);
    end

    % Combine data sets if relevant
    data.dataSet = repmat({dataset}, size(data,1), 1);
    if iFile==1
        dataTable = data;
    else
        columnsA = ismember(dataTable.Properties.VariableNames,data.Properties.VariableNames);
        columnsB = ismember(data.Properties.VariableNames,dataTable.Properties.VariableNames);
        dataTable = [dataTable(:,columnsA); data(:,columnsB)];
    end
end

end

