function [dataTable,ROIsToProcess,ROIlogicals,mapToNewROI,mapToRSGroup] = loadGoodData(varargin)

o = ecogutils.postHocOptionsParser(varargin{:});

dataTable = loadECoG.loadMergedDataFiles(o);

ROI_table = ecogutils.loadROItable();
mapToNewROI = containers.Map(ROI_table.oldROI,ROI_table.newROI);
mapToRSGroup = containers.Map(ROI_table.oldROI,ROI_table.RSGroup);

ROIsToProcess = cell(1,size(ROI_table,1));
for iROI = 1:size(ROI_table,1)
    ROIsToProcess{iROI} = [ROI_table.newROI{iROI} '_' ROI_table.RSGroup{iROI}];
end
ROIsToProcess = unique(ROIsToProcess,'stable');

ROIlogicals = cellfun(@(x) contains(ROIsToProcess, x), {'_'},'UniformOutput',false);

%% Keep only goodChans
for iRow = 1:size(dataTable,1)
    % Get contact-sorted channel data
    
    dataTable.ECoGchannels{iRow} = dataTable.ECoGchannels{iRow}(dataTable.indexChans{iRow});
    segments = fieldnames(dataTable.(o.measure){iRow});
    for iSeg = 1:length(segments)
        if contains(o.measure,'envelope')
            dataTable.(o.measure){iRow}.(segments{iSeg}).env = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).env,dataTable.indexChans{iRow},2);
        elseif contains(o.measure,'wPLI_dbt_spectrum')
            dataTable.(o.measure){iRow}.(segments{iSeg}).wPLI_spectrum = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).wPLI_spectrum,dataTable.indexChans{iRow},1:2);
        elseif contains(o.measure,'wPLI')
            dataTable.(o.measure){iRow}.(segments{iSeg}).wPLI_debias = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).wPLI_debias,dataTable.indexChans{iRow},1:2);
        elseif contains(o.measure,'envCorrDBT')
            dataTable.(o.measure){iRow}.(segments{iSeg}).envCorr = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).envCorr,dataTable.indexChans{iRow},1:2);
        elseif contains(o.measure,'rawData')
            dataTable.(o.measure){iRow}.(segments{iSeg}).data = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).data,dataTable.indexChans{iRow},2);
        else
            dataTable.(o.measure){iRow}.(segments{iSeg}).powspctrm = ecogutils.subsetNested(dataTable.(o.measure){iRow}.(segments{iSeg}).powspctrm,dataTable.indexChans{iRow},1);
        end
        if ismember('specAnalysis',dataTable.Properties.VariableNames)
            dataTable.specAnalysis{iRow}.(segments{iSeg}).powspctrm = ecogutils.subsetNested(dataTable.specAnalysis{iRow}.(segments{iSeg}).powspctrm,dataTable.indexChans{iRow},1);
        end
    end
    

    
end

dataTable.segNames = cellfun(@fieldnames,dataTable.(o.measure),'UniformOutput',false);

dataTable.(o.measure) = cellfun(@struct2cell,dataTable.(o.measure),'UniformOutput',false);

%% Segment rejection
useSegments = cellfun(@(y) cellfun(@(x) (sum(x)/length(x))>2/3, y), dataTable.segMask,'UniformOutput',false);
for iRow = 1:size(dataTable,1)
    dataTable.segNames{iRow} = dataTable.segNames{iRow}(useSegments{iRow});
    dataTable.segmentTimes{iRow} = dataTable.segmentTimes{iRow}(useSegments{iRow});
    dataTable.segmentTimeOfDay{iRow} = dataTable.segmentTimeOfDay{iRow}(useSegments{iRow});
    dataTable.(o.measure){iRow} = dataTable.(o.measure){iRow}(useSegments{iRow});
end

%% Look for fmri
for iRow = 1:size(dataTable,1)
    thisSubj = dataTable.patientID{iRow};
    fmriDir = ['Q:\Imaging\AnalysisOutput\ElectrodeSelectedFmriData\' thisSubj(1:3)];
    if exist(fmriDir,'dir')
        fmriFile = [fmriDir filesep thisSubj(1:3) '_pearson_corr' dataTable.electrodeSheet{iRow} ' Rev' dataTable.electrodeRev{iRow} '.xlsx'];
        fmriFilealt = [fmriDir filesep thisSubj(1:3) '_pearson_corr' dataTable.electrodeSheet{iRow} ' Rev ' dataTable.electrodeRev{iRow} '.xlsx'];
        if exist(fmriFile,'file') || exist(fmriFilealt,'file')
            if exist(fmriFile,'file')
                fmriAdj = readmatrix(fmriFile);
            else
                fmriAdj = readmatrix(fmriFilealt);
            end
            fmriChans = fmriAdj(2:end,1);
            fmriAdj = fmriAdj(2:end,2:end);
            
            [~,idx1,idx2] = intersect([dataTable.ECoGchannels{iRow}.contNum],fmriChans,'stable');
            
            fmriMatch = nan(length(dataTable.ECoGchannels{iRow}));
            fmriMatch(idx1,idx1) = (fmriAdj(idx2,idx2)+fmriAdj(idx2,idx2)')/2;
            fmriMatch(logical(eye(size(fmriMatch)))) = nan;
            dataTable.fmri{iRow} = struct('fMRI_pearson',fmriMatch);
        end
    else
        continue
    end
    
end

%% Map states

states = cell(size(dataTable,1),1);
for iRow = 1:size(dataTable,1)
    [states{iRow},o.StateMap] = remapStates(dataTable(iRow,:),o.StateMap);
end
dataTable.states = states;

%% function remapStates
    function [states,stateMap] = remapStates(data,stateMap)
        if size(data,1)>1
            error('remapping operates on single rows')
        end
        
        states = extractBefore(data.segNames{1},'_');
        
        % Are there any states not in our map?
        newStates = unique(states(~ismember(states,keys(stateMap))));
        % Add any new states to our map, if they exist
        if ~isempty(newStates)
            stateMap = [stateMap; containers.Map(newStates,newStates)];
        end
        
        states = values(stateMap,states);
        
    end

end