function [newObj] = avgByROI(obj,ROIs)
%avgByROI Average adjacency matrix by ROI
%   If ROIs defined, output will have shape of length ROIs x ROIs and
%   include NaN for missing values, otherwise ROIs will come from input
%   object
newObj(numel(obj)) = AdjMatrix;
for iEl = 1:numel(obj)
    roi = obj(iEl).ROI;

    if nargin<2
        ROIs = unique(roi,'stable');
    end

    nROI = length(ROIs);
    avgAdj = nan(nROI,nROI,size(obj(iEl).Adj,3));

    for iROI=1:nROI
        iiLogic = ismember(roi,ROIs{iROI});
        for jROI=iROI:nROI
            jjLogic = ismember(roi,ROIs{jROI});
            avgAdj(iROI,jROI,:) = mean(obj(iEl).Adj(iiLogic,jjLogic,:),[1,2]);
            avgAdj(jROI,iROI,:) = avgAdj(iROI,jROI,:);
        end
    end

    metaData = struct('ROI',ROIs);
    newObj(iEl) = AdjMatrix(avgAdj,metaData);
end

end
