function [] = sortByROI(obj,ROI_table,majorROI,minorROI,suppressWarning)
%sortByROI Sort adjacency matrix by ROI_table
%   ROIs are sorted first by majorROI, then minorROI, then by proximity to HGPM or ycoord

for iEl = 1:numel(obj)

    %% Default is to sort first by newROINum, second by oldROINum
    if nargin<3 || isempty(majorROI)
        majorROI = 'newROINum';
    end
    if nargin<4 || isempty(minorROI)
        minorROI = 'oldROINum';
    end
    if nargin<5
        suppressWarning = false;
    end

    ROIs = obj(iEl).ROI;

    %% Compare oldROIs to ROI_table to get first and second sort conditions
    firstSort = zeros(length(ROIs),1)-1;
    secondSort = zeros(length(ROIs),1)-1;
    secondSortID = zeros(length(ROIs),1)-1;

    for iROI = 1:size(ROI_table,1)
        firstSort(ismember(ROIs,ROI_table.oldROI{iROI})) = ROI_table.(majorROI)(iROI);
        secondSort(ismember(ROIs,ROI_table.oldROI{iROI})) = ROI_table.(minorROI)(iROI);
        secondSortID(ismember(ROIs,ROI_table.oldROI{iROI})) = iROI;
    end

    %% Final sort condition is distance from the middle of HGPM, if available

    if isfield(obj(iEl).MetaData,'MNIX') && isfield(obj(iEl).MetaData,'MNIY') && isfield(obj(iEl).MetaData,'MNIZ')
        if ischar([obj(iEl).MetaData.MNIX])
            xCoord = str2double({obj(iEl).MetaData.MNIX});
        else
            xCoord = [obj(iEl).MetaData.MNIX];
        end
        if ischar([obj(iEl).MetaData.MNIY])
            yCoord = str2double({obj(iEl).MetaData.MNIY});
        else
            yCoord = [obj(iEl).MetaData.MNIY];
        end
        if ischar([obj(iEl).MetaData.MNIZ])
            zCoord = str2double({obj(iEl).MetaData.MNIZ});
        else
            zCoord = [obj(iEl).MetaData.MNIZ];
        end
    else
        xCoord = [obj(iEl).MetaData.xCoord];
        yCoord = [obj(iEl).MetaData.yCoord];
        zCoord = [obj(iEl).MetaData.zCoord];
    end
    HGPMchans = strcmp(ROIs,'HGPM');
    HGPMXPos = mean(xCoord(HGPMchans));
    HGPMYPos = mean(yCoord(HGPMchans));
    HGPMZPos = mean(zCoord(HGPMchans));

    if strcmp(majorROI,'newROINum')
        thirdSort = ((xCoord-HGPMXPos).^2 + (yCoord-HGPMYPos).^2 + (zCoord-HGPMZPos).^2).^0.5;
    else
        thirdSort = yCoord;
    end
    thirdSort(isnan(thirdSort)) = 1000000;


    %% Do the sort
    [~,sortIndex] = sortrows([firstSort secondSort thirdSort']);

    %% Exclude ROIs that have -1 for sortIndex (or are not in ROI_table)
    notInROITable = find(secondSort==-1);
    for ii = 1:length(notInROITable)
        if ~ismember(ROIs{notInROITable(ii)},{'SZ','WM','Thal','EKG','Unc'})
            if ~suppressWarning
                 disp([ROIs{notInROITable(ii)} ' not in ROI_table'])
            end
        end
    end

    firstSort = firstSort(sortIndex);
    secondSort = secondSort(sortIndex);
%     secondSortID = secondSortID(sortIndex);

    keepIndices = firstSort~=-1 & secondSort~=-1 & ~isnan(firstSort) & ~isnan(secondSort);

    sortIndex = sortIndex(keepIndices);
%     firstSort = firstSort(keepIndices);
%     secondSort = secondSort(keepIndices);
%     secondSortID = secondSortID(keepIndices);

    obj(iEl).index(sortIndex);

%     obj(iEl).majorROI_ID = majorROI_ID;
%     obj(iEl).minorROI_ID = minorROI_ID;
end

end