function [centroidDist] = centroidDist(obj,clusters,nCluster,useChans,maxDimension)
%centroidDist Euclidean distance between centroids
%   clusters = Integer indices identifying clusters
%   nCluster = Number of clusters overall
%   useChans (optional) = logical array of channels to use
%   maxDimension (optional) = Use all dimensions from the second to this
%   dimension; if omitted, use elbow

if nargin<3 || isempty(useChans)
    useChans = true(size(obj.Emb,1));
end

if nargin<4 || isempty(maxDimension)
    maxDimension = obj.Elbow;
end

[~,~,ic] = unique(clusters(useChans));

centroidDist = nan(nCluster);

emb = obj.Emb(useChans,2:maxDimension);

        for iROI = 1:(nCluster-1)
            centroid1 = mean(emb(ic==iROI,:),1);
            for jROI = (iROI+1):nCluster
                centroid2 = mean(emb(ic==jROI,:),1);
                centroidDist(iROI,jROI) = log10(norm(centroid1-centroid2));
            end
        end
end