clear
close all
load('AllFigureData.mat');
savePlots = 1;

%% DEPENDENCIES
% ecogutils.plotAdj
% ecogutils.scatterText

%% Figure 2
f2bName = 'Fig2b Example normalized adjacency matrix';
f2b = figure('Name',f2bName);
ecogutils.plotAdj(fig2.Psymm,1:size(fig2.Psymm,1),fig2.colorMap,false);
f2cName = 'Fig2c Example embedding';
f2c = figure('Name',f2cName,'Position',[138 83 929 900]);
tiledlayout(3,1,'TileSpacing','compact','Padding','none')
nexttile(1);
plotEmbed(fig2.Emb(:,2:4),[0,90],fig2.ROIlabels,fig2.colorMap,[]);
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(2);
plotEmbed(fig2.Emb(:,2:4),[0,0],fig2.ROIlabels,fig2.colorMap,[]);
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(3);
plotEmbed(fig2.Emb(:,[2,3,5]),[0,0],fig2.ROIlabels,fig2.colorMap,[],{'dim1','dim2','dim4'});
if savePlots
    saveas(f2b,[f2bName '.fig']);
    saveas(f2c,[f2cName '.fig']);
end
%% Figure 3

f3aName = 'Fig3a Average adj mat, spectrum';
f3a = figure('Name',f3aName,'Position',[134 10 1524 771]);
subplot(1,2,1);
ecogutils.plotAdj(fig3.Psymm,1:size(fig3.Psymm,1),fig3.colorMap,false);
subplot(1,2,2);
plot(1:length(fig3.eVals)-1,abs(fig3.eVals(2:end)),'-ok');
xlabel('Eigenvalue number')
ylabel('|\lambda|')

f3bName = 'Fig3b Average embedding - t1';
f3b = plotAvgEmbedding(fig3,f3bName);

if savePlots
    saveas(f3a,[f3aName '.fig']);
    saveas(f3b,[f3bName '.fig']);
end

%% Figure 4 - dendrogram for t=1

f4Name = ['Fig4 - Dendrogram from RS emb - gammaEnv - t1'];
f4 = plotDendrogram(fig45,f4Name);

if savePlots
    saveas(f4,[f4Name '.fig']);
end


%% Figure 5 Hubness

f5bName = ['Fig5b - Hubness'];

f5b = plotHubness(fig45,f5bName);
if savePlots
    saveas(f5b,[f5bName '.fig']);
end



%% Supp Fig2
sf2Name = 'Suppl Fig2 SNR';
sf2 = figure('Name',sf2Name,'Position',[65 446 539 504]);
hold on;
plot([.3 2],[.3 2],'k-')
scatter(figS2.adjMatSNR,figS2.embDistSNR,'k');

a = gca;
a.XScale = 'log';
a.YScale = 'log';
axis equal
axis square
xlabel('Connectivity matrix SNR')
ylabel('Embedding distance matrix SNR')
set(a,'XTick',[.5 1 2])
set(a,'YTick',[.5 1 2])
xlim([.3 2])
if savePlots
    saveas(sf2,[sf2Name '.fig']);
end




%% Supp Fig 8
sf8Name = 'Suppl Fig8 DomNondom Embedding';
sf8 = figure('Name',sf8Name,'Position',[138 83 929 900]);
ti=tiledlayout(3,3,'TileSpacing','compact','Padding','none');
nexttile(1);
plotEmbed(figS5.bothEmb(:,2:4),[0,90],figS5.ROIs,figS5.colorMap,[]);
title('All')
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(4);
plotEmbed(figS5.bothEmb(:,[2,4,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(7);
plotEmbed(figS5.bothEmb(:,[2,5,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim4','dim2'});

nexttile(2);
plotEmbed(figS5.domMapped(:,2:4),[0,90],figS5.ROIs,figS5.colorMap,[]);
title('Language Dom')
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(5);
plotEmbed(figS5.domMapped(:,[2,4,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(8);
plotEmbed(figS5.domMapped(:,[2,5,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim4','dim2'});
ax = gca;
ax.YTickLabel = {};
ylabel('');

nexttile(3);
plotEmbed(figS5.nondomMapped(:,2:4),[0,90],figS5.ROIs,figS5.colorMap,[]);
title('Language Non-dom')
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(6);
plotEmbed(figS5.nondomMapped(:,[2,4,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(9);
plotEmbed(figS5.nondomMapped(:,[2,5,3]),[0,90],figS5.ROIs,figS5.colorMap,[],{'dim1','dim4','dim2'});
ax = gca;
ax.YTickLabel = {};
ylabel('');
plotutils.setConstantAxesLim(ti,1:9);

if savePlots
    saveas(sf8,[sf8Name '.fig']);
end


%% Figure 6a

ROIList = figS5.ROIs;
nROIs = length(ROIList);
minDim = 2;
maxDim = 5;
dist = zeros(1,nROIs);
early = zeros(1,nROIs);
late = zeros(1,nROIs);
for iROI = 1:nROIs
    thisROI = ROIList{iROI};
    dist(iROI) = norm(figS5.domMapped(iROI,minDim:maxDim)-figS5.nondomMapped(iROI,minDim:maxDim));
    early(iROI) = audResp.perc_higamma_early(strcmp(audResp.ROI,thisROI));
    late(iROI) = audResp.perc_higamma_late(strcmp(audResp.ROI,thisROI));
end

f6aName = 'Fig6a - DomNonDom vs Auditory responsiveness';

f6a = figure('Name',f6aName);
subplot(1,2,1);
hold on
for iROI = 1:length(ROIList)
    plot(early(iROI),dist(iROI),'o','MarkerFaceColor',figS5.colorMap(iROI,:),...
        'MarkerEdgeColor',figS5.colorMap(iROI,:),'MarkerSize',8);
end

ax = gca;
ax.XLim = [-2.5,100];
ax.YLim = [0.0,0.12];
ax.XLabel.String = '% auditory responsive sites';
ax.YLabel.String = 'D(dominant,non-domominant)';
ax.FontSize = 14;
ax.Title.String = ['Early (50-350 ms)'];

subplot(1,2,2);
hold on
for iROI = 1:length(ROIList)
    plot(late(iROI), dist(iROI),'^','MarkerFaceColor',figS5.colorMap(iROI,:),...
        'MarkerEdgeColor',figS5.colorMap(iROI,:),'MarkerSize',8);
end

ax = gca;
ax.XLim = [-2.5,100];
ax.YLim = [0.0,0.12];
ax.FontSize = 14;
ax.Title.String = ['Late (350-650 ms)'];

if savePlots
    saveas(f6a,[f6aName '.fig']);
end


%% Figure 6b

f6Name = 'Fig6 Embedding distances by hemisphere';
f6b = figure('Name',f6Name);
subplot(1,2,1)
hold on;
scatter(figS5.domDistAll,figS5.nondomDistAll,'k')
xlim([0 max([figS5.domDistAll],[],'all')*1.2])
ylim([0 max([figS5.domDistAll],[],'all')*1.2])
xlabel('Dominant hemisphere distance')
ylabel('Non-dominant hemisphere distance')
rh = refline(1,0);
rh.Color = 'k';
title('All connections')
axis square;

subplot(1,2,2)
hold on;
scatter(figS5.domDistLang,figS5.nondomDistLang,'k')
xlim([0 max([figS5.domDistAll],[],'all')*1.2])
ylim([0 max([figS5.domDistAll],[],'all')*1.2])
xlabel('Dominant hemisphere distance')
ylabel('Non-dominant hemisphere distance')
rh = refline(1,0);
rh.Color = 'k';
title('Within language-specialized connections')
axis square;

if savePlots
    saveas(f6b,[f6Name '.fig']);
end


%% Suppl Fig 5
sf5Name = 'Suppl Fig5 - Embedding Distance Correlations';
sf5 = figure('Name',sf5Name,'Position',[138 83 929 900]);
tiledlayout(1,2,'TileSpacing','compact','Padding','none');
nexttile(1);
hold on;
grayScaleVals = gray;
grayScaleVals = flipud(grayScaleVals);
colormap(grayScaleVals);
% figS6.corrMatrix(isnan(figS6.corrMatrix)) = 0;
imagesc(figS6.corrMatrix,[0 1]);
set(gca,'XTick',1:length(figS6.labels),'XTickLabels',figS6.labels);
set(gca,'YTick',1:length(figS6.labels),'YTickLabels',figS6.labels);
xtickangle(90)
for ii=1:length(figS6.labels)
    for jj=1:length(figS6.labels)
        %if ii~=jj
        text(jj,ii,num2str(figS6.corrMatrix(ii,jj),2),'HorizontalAlignment','center','Color',[1 1 1]);
        %end
    end
end

axis square;
ax = gca;
ax.Color = 'none'; % turn off white box background
%ax.XColor = 'w';
%ax.YColor = 'w';
ax.YDir = 'reverse';

if savePlots
    saveas(sf5,[sf5Name '.fig']);
end

%% Suppl Fig5b
sf5bName = 'Suppl Fig5b - Embedding Distance Correlations Sensitivity';
sf5b = figure('Name',sf5bName,'Position',[138 83 929 900]);
tiledlayout(1,2,'TileSpacing','compact','Padding','none');
nexttile(1);
hold on;
grayScaleVals = gray;
grayScaleVals = flipud(grayScaleVals);
colormap(grayScaleVals);
imagesc(figS6b.corrMatrix,[0 1]);
set(gca,'XTick',1:length(figS6b.labels),'XTickLabels',figS6b.labels);
set(gca,'YTick',1:length(figS6b.labels),'YTickLabels',figS6b.labels);
xtickangle(90)
for ii=1:length(figS6b.labels)
    for jj=1:length(figS6b.labels)
        %if ii~=jj
        text(jj,ii,num2str(figS6b.corrMatrix(ii,jj),2),'HorizontalAlignment','center','Color',[1 1 1]);
        %end
    end
end

axis square;
ax = gca;
ax.Color = 'none'; % turn off white box background
%ax.XColor = 'w';
%ax.YColor = 'w';
ax.YDir = 'reverse';

if savePlots
    saveas(sf5b,[sf5bName '.fig']);
end

%% Suppl F3 all 4 pairwise plots for t=1
sf3Name = 'Suppl Fig3 - Average Embedding 4 dimensions - t1';
sf3 = figure('Name',sf3Name,'Position',[138 83 929 900]);
tiledlayout(3,3,'TileSpacing','compact','Padding','none')
nexttile(1);
plotEmbed(fig3.bootstrapMn(:,2:4),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,2:4),{'','dim2','dim3'});
ax = gca;
ax.XTickLabel = {};
nexttile(4);
plotEmbed(fig3.bootstrapMn(:,[2 4 3]),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,[2 4 3]),{'','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
nexttile(7);
plotEmbed(fig3.bootstrapMn(:,[2 5 3]),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,[2 5 3]),{'dim1','dim4','dim2'});

nexttile(5);
plotEmbed(fig3.bootstrapMn(:,[3 4 2]),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,[3 4 2]),{'','','dim1'});
ax = gca;
ax.XTickLabel = {};
ax.YTickLabel = {};
nexttile(8);
plotEmbed(fig3.bootstrapMn(:,[3 5 2]),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,[3 5 2]),{'dim2','','dim1'});
ax = gca;
ax.YTickLabel = {};
nexttile(9);
plotEmbed(fig3.bootstrapMn(:,[4 5 2]),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,[4 5 2]),{'dim3','','dim1'});
ax = gca;
ax.YTickLabel = {};
if savePlots
    saveas(sf3,[sf3Name '.fig']);
end


%% Suppl Fig 1 all 4 pairwise plots example subject
sf1Name = 'Suppl Fig1 - Example Subject Embedding 4 dimensions';
sf1 = figure('Name',sf1Name,'Position',[138 83 929 900]);
tiledlayout(3,3,'TileSpacing','compact','Padding','none')
nexttile(1);
plotEmbed(fig2.Emb(:,2:4),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'','dim2','dim3'});
ax = gca;
ax.XTickLabel = {};
nexttile(4);
plotEmbed(fig2.Emb(:,[2 4 3]),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
nexttile(7);
plotEmbed(fig2.Emb(:,[2 5 3]),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'dim1','dim4','dim2'});

nexttile(5);
plotEmbed(fig2.Emb(:,[3 4 2]),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'','','dim1'});
ax = gca;
ax.XTickLabel = {};
ax.YTickLabel = {};
nexttile(8);
plotEmbed(fig2.Emb(:,[3 5 2]),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'dim2','','dim1'});
ax = gca;
ax.YTickLabel = {};
nexttile(9);
plotEmbed(fig2.Emb(:,[4 5 2]),[0,90],fig2.ROIlabels,fig2.colorMap,[],{'dim3','','dim1'});
ax = gca;
ax.YTickLabel = {};
if savePlots
    saveas(sf1,[sf1Name '.fig']);
end

%% Figure 7
f7Name = 'Fig7 - Ephys fMRI comparison';
f7 = figure('Name',f7Name,'Position',[138 83 929 900]);
tiledlayout(3,3,'TileSpacing','compact','Padding','none')


% Reverse arbitrary direction of axes to put HGPM on the left
fig7.fMRIAvgEmb(:,2:4) = fig7.fMRIAvgEmb(:,2:4)*-1;
fig7.remappedEphysAvgEmbedding(:,2:4) = fig7.remappedEphysAvgEmbedding(:,2:4)*-1;

nexttile(1);
plotEmbed(fig7.fMRIAvgEmb(:,2:4),[0,90],fig7.ROInames,fig7.ROIcolors,[]);
title('fMRI')
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(4);
plotEmbed(fig7.fMRIAvgEmb(:,[2,4,3]),[0,90],fig7.ROInames,fig7.ROIcolors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(7);
plotEmbed(fig7.fMRIAvgEmb(:,[2,5,3]),[0,90],fig7.ROInames,fig7.ROIcolors,[],{'dim1','dim4','dim2'});

nexttile(2);
plotEmbed(fig7.remappedEphysAvgEmbedding(:,2:4),[0,90],fig7.ROInames,fig7.ROIcolors,[]);
title('iEEG')
ax = gca;
ax.XTickLabel = {};
xlabel('');
% ax.YTickLabel = {};
ylabel('');
nexttile(5);
plotEmbed(fig7.remappedEphysAvgEmbedding(:,[2,4,3]),[0,90],fig7.ROInames,fig7.ROIcolors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
% ax.YTickLabel = {};
ylabel('');
nexttile(8);
plotEmbed(fig7.remappedEphysAvgEmbedding(:,[2,5,3]),[0,90],fig7.ROInames,fig7.ROIcolors,[],{'dim1','dim4','dim2'});
ax = gca;
% ax.YTickLabel = {};
ylabel('');

nexttile(3);
title('Pairwise Distance')
cla
hold on;

%RGBtriplets = cellfun(@(x) [hex2dec(x(2:3)) hex2dec(x(4:5)) hex2dec(x(6:7))]/255,cellstr(fig7.pairwise_ROI_distance_colors),'UniformOutput',false);

scatter(fig7.fmriDist,fig7.ephysDist,4,'k','filled')
lsline();

xlim([0,max(fig7.fmriDist)*1.15]);
ylim([0,max(fig7.ephysDist)*1.15]);
ax = gca;
% ax.XTickLabel = {};
xlabel('fMRI');
% ax.YTickLabel = {};
ylabel('iEEG');
text(0.05,0.95,['r = ' num2str(fig7.avgCorr(2),2)],'Units','normalized')

nexttile(6);
title('fMRI vs iEEG')
hold on;
plot(1:length(fig7.ephysMeasureNames),fig7.avgCorr(1:length(fig7.ephysMeasureNames)),'ok','LineWidth',2)
ylim([0 0.7])
xlim([0.5 length(fig7.ephysMeasureNames)+0.5])
ylabel('correlation')
ax = gca;
ax.XTick = 1:length(fig7.ephysMeasureNames);
ax.XTickLabel = fig7.ephysMeasureNames;
% xlabel('');
% ax.YTickLabel = {};
% ylabel('');
if savePlots
    saveas(f7,[f7Name '.fig']);
end

%% Figure 8
f8Name = 'Fig8 - fMRI effect of coverage';
f8 = figure('Name',f8Name,'Position',[138 83 929 900]);
tiledlayout(4,4,'TileSpacing','compact','Padding','none')

fig8.fullEmb(:,[2 5]) = fig8.fullEmb(:,[2 5]) * -1;
fig8.subsetFullEmb(:,[2 5]) = fig8.subsetFullEmb(:,[2 5]) * -1;

fig8.fullColors = fig8.fullColors/255;
fig8.otherColors = fig8.otherColors/255;
%RGBtripletsFull = cell2mat(cellfun(@(x) [hex2dec(x(2:3)) hex2dec(x(4:5)) hex2dec(x(6:7))]/255,cellstr(fig8.full_fMRI_avgROI_embedding_colors),'UniformOutput',false));
%RGBtripletsOther = cell2mat(cellfun(@(x) [hex2dec(x(2:3)) hex2dec(x(4:5)) hex2dec(x(6:7))]/255,cellstr(fig8.all_other_embedding_colors),'UniformOutput',false));

nexttile(1);
plotEmbed(fig8.fullEmb(:,2:4),[0,90],[],fig8.fullColors,[]);
title('Full fMRI')
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(5);
plotEmbed(fig8.fullEmb(:,[2,4,3]),[0,90],[],fig8.fullColors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(9);
plotEmbed(fig8.fullEmb(:,[2,5,3]),[0,90],[],fig8.fullColors,[],{'dim1','dim4','dim2'});

nexttile(2);
plotEmbed(fig8.subsetFullEmb(:,2:4),[0,90],[],fig8.otherColors,[]);
title('Full fMRI (subset shown)')
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(6);
plotEmbed(fig8.subsetFullEmb(:,[2,4,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(10);
plotEmbed(fig8.subsetFullEmb(:,[2,5,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim4','dim2'});
ax = gca;
ax.YTickLabel = {};
ylabel('');

nexttile(3);
plotEmbed(fig8.partialEmb(:,2:4),[0,90],[],fig8.otherColors,[]);
title('Partial fMRI')
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(7);
plotEmbed(fig8.partialEmb(:,[2,4,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(11);
plotEmbed(fig8.partialEmb(:,[2,5,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim4','dim2'});
ax = gca;
ax.YTickLabel = {};
ylabel('');

nexttile(4);
plotEmbed(fig8.sitelevelEmbBasisChanged(:,2:4),[0,90],[],fig8.otherColors,[]);
title('Partial fMRI by Electrode')
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(8);
plotEmbed(fig8.sitelevelEmbBasisChanged(:,[2,4,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim3','dim2'});
ax = gca;
ax.XTickLabel = {};
xlabel('');
ax.YTickLabel = {};
ylabel('');
nexttile(12);
plotEmbed(fig8.sitelevelEmbBasisChanged(:,[2,5,3]),[0,90],[],fig8.otherColors,[],{'dim1','dim4','dim2'});
ax = gca;
ax.YTickLabel = {};
ylabel('');

nexttile(13);
title('Pairwise Distance')
cla
hold on;

%RGBtriplets = cellfun(@(x) [hex2dec(x(2:3)) hex2dec(x(4:5)) hex2dec(x(6:7))]/255,cellstr(fig8.pairwise_ROI_distance_colors),'UniformOutput',false);

scatter(fig8.fullDist,fig8.partialDist,4,'k','filled')
lsline();

xlim([0,max(fig8.fullDist)*1.15]);
ylim([0,max(fig8.partialDist)*1.15]);
ax = gca;
% ax.XTickLabel = {};
xlabel('Full fMRI');
% ax.YTickLabel = {};
ylabel('Partial fMRI');
text(0.05,0.95,['r = ' num2str(fig8.fullvpartial(fig8.exSubj),2)],'Units','normalized')
axis square;

nexttile(14,[1,2]);
boxplot([fig8.fullvpartial fig8.sitevROI])
ylim([0 max([fig8.fullvpartial' fig8.sitevROI'],[],'all')*1.15])
ylabel('correlation')
ax = gca;
ax.XTick = 1:2;
ax.XTickLabel = {'Full vs Partial','ROI vs Electrode','Full vs Electrode'};
title('Embedding Distance Correlations')

% schaefer7_names = cellstr(squeeze(fig8.schaefer7_network_colors(:,1,:)));
% schaefer7_colors = cellstr(squeeze(fig8.schaefer7_network_colors(:,2,:)));
% schaefer7_colors = cellfun(@(x) [hex2dec(x(2:3)) hex2dec(x(4:5)) hex2dec(x(6:7))]/255,schaefer7_colors,'UniformOutput',false);

nexttile(16);
cla;
hold on;

% for ii=1:length(schaefer7_names)
%     scatter(0,0,4,schaefer7_colors{ii},'filled');
% end
%
% legend(schaefer7_names);
set(gca,'Visible','off')
if savePlots
    saveas(f8,[f8Name '.fig']);
end


%% Other bands & measures


%%
% Avg emb other dimensions for t=1
minDim = 2;
elbowDim = [7, 5, 8, 7, 7]; %high gamma, gamma, beta, alpha, theta
fields = fieldnames(fig3allbands);
fields = fields(contains(fields,'envCorr'));
bands = split(fields,'_');
bands = bands(:,2);
for iBand = 3
    data = fig3allbands.(fields{iBand});
    otherAvgEmb = ['Suppl Fig4 Average embedding 4D - t1 - ' bands{iBand}];
    otherAvgEmbFig = figure('Name',otherAvgEmb,'Position',[138 83 929 900]);
    tiledlayout(3,3,'TileSpacing','compact','Padding','none')
    nexttile(1);
    plotEmbed(data.bootstrapMn(:,minDim:4),[0,90],data.ROIs,data.colorMap,data.bootstrapSD(:,minDim:4),{'','dim2','dim3'});
    ax = gca;
    ax.XTickLabel = {};
    nexttile(4);
    plotEmbed(data.bootstrapMn(:,[2 4 3]),[0,90],data.ROIs,fig3.colorMap,data.bootstrapSD(:,[2 4 3]),{'','dim3','dim2'});
    ax = gca;
    ax.XTickLabel = {};
    nexttile(7);
    plotEmbed(data.bootstrapMn(:,[2 5 3]),[0,90],data.ROIs,fig3.colorMap,data.bootstrapSD(:,[2 5 3]),{'dim1','dim4','dim2'});
    
    nexttile(5);
    plotEmbed(data.bootstrapMn(:,[3 4 2]),[0,90],data.ROIs,fig3.colorMap,data.bootstrapSD(:,[3 4 2]),{'','','dim1'});
    ax = gca;
    ax.XTickLabel = {};
    ax.YTickLabel = {};
    nexttile(8);
    plotEmbed(data.bootstrapMn(:,[3 5 2]),[0,90],data.ROIs,fig3.colorMap,data.bootstrapSD(:,[3 5 2]),{'dim2','','dim1'});
    ax = gca;
    ax.YTickLabel = {};
    nexttile(9);
    plotEmbed(data.bootstrapMn(:,[4 5 2]),[0,90],data.ROIs,fig3.colorMap,data.bootstrapSD(:,[4 5 2]),{'dim3','','dim1'});
    ax = gca;
    ax.YTickLabel = {};
    if savePlots
        saveas(otherAvgEmbFig,[otherAvgEmb '.fig']);
    end
end

%% dendrograms for t=1
minDim = 2;
rotateFlag = 1;
elbowDim = [7, 5, 8, 7, 7]; %high gamma, gamma, beta, alpha, theta
fields = fieldnames(fig45allbands);
fields = fields(contains(fields,'envCorr'));
bands = split(fields,'_');
bands = bands(:,2);
for iBand = 1:length(bands)
    dendrFigName = ['Suppl Fig6 Dendrogram t1 - ' bands{iBand}];
    data = fig45allbands.(fields{iBand});
    maxDim = elbowDim(iBand);
    [ctrDist.(bands{iBand})] = calcCtrDist(data,minDim,maxDim);
    dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
    if savePlots
        saveas(dendFig,[dendrFigName '.fig']);
    end
end



%% dendrograms for other thresholds
minDim = 2;
rotateFlag = 1;
%elbowDim = [5, 5, 8, 9]; %10, 20, 40, 50
dendrFigName = ['Suppl FigX Dendrogram t1 - thresh10'];
data = fig45t10;
maxDim = 5;
dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
if savePlots
    saveas(dendFig,[dendrFigName '.fig']);
end

dendrFigName = ['Suppl FigX Dendrogram t1 - thresh20'];
data = fig45t20;
maxDim = 5;
dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
if savePlots
    saveas(dendFig,[dendrFigName '.fig']);
end

dendrFigName = ['Suppl FigX Dendrogram t1 - thresh40'];
data = fig45t40;
maxDim = 8;
dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
if savePlots
    saveas(dendFig,[dendrFigName '.fig']);
end

dendrFigName = ['Suppl FigX Dendrogram t1 - thresh50'];
data = fig45t50;
maxDim = 9;
dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
if savePlots
    saveas(dendFig,[dendrFigName '.fig']);
end

dendrFigName = ['Suppl FigX Dendrogram multiscale'];
data = fig45multiscale;
maxDim = 5;
dendFig = plotDendrogram(data,dendrFigName,minDim,maxDim,rotateFlag);
if savePlots
    saveas(dendFig,[dendrFigName '.fig']);
end



%% Hubness 1-D
minDim = 2;
elbowDim = [7, 5, 8, 7, 7]; %high gamma, gamma, beta, alpha, theta
fields = fieldnames(fig45allbands);
fields = fields(contains(fields,'envCorr'));
bands = split(fields,'_');
bands = bands(:,2);
for iBand = 1:length(bands)
    data = fig45allbands.(fields{iBand});
    maxDim = elbowDim(iBand);
    [ctrDist.(bands{iBand})] = calcCtrDist(data,minDim,maxDim);
end

hub1DFigName = 'Fig5c Hubness1D';
hub1DFig = plotHubness1D(ctrDist,hub1DFigName,fig45.ROIs,fig45.colorMap);
if savePlots
    saveas(hub1DFig,[hub1DFigName '.fig']);
end

%% Data for stability table
makeStabTable;



%% Suppl - movie of spinning ROIs in dims 2-4
mov1Name = 'Average emb movie dims 2-4';
figure('Name',mov1Name,'Position',[134 10 900 771]);
fontSize = 10;
faceAlpha = 0.15;
fontWeight = 'bold';
plotEmbed(fig3.bootstrapMn(:,2:4),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,2:4),...
    {'Dimension 1','Dimension 2','Dimension 3'},fontSize,fontWeight,faceAlpha);

ax = gca;
ax.XLabel.FontSize = 14; ax.XLabel.Rotation = 5;
ax.YLabel.FontSize = 14; ax.YLabel.Rotation = 295;
ax.ZLabel.FontSize = 14;
%ax.Title.String = 'RS group avg - \gamma env corrs';
ax.XGrid = 'on'; %ax.XAxis.Visible = 'off';
ax.YGrid = 'on'; %ax.YAxis.Visible = 'off';
ax.ZGrid = 'on'; %ax.ZAxis.Visible = 'off';
ax.Projection = 'perspective';

startPos = [0.7748,-0.7897];
ax.View = startPos;
ax.CameraViewAngle=-25;
ax.CameraPosition = [0.5,2,0.5];

OptionZ.FrameRate=15;OptionZ.Duration=10;OptionZ.Periodic=true;
h = ax.Children;

origPt = [1,0,0];
direPt = [0,0,0];
light('Position',[1 1 1],'Style','infinit','Color',[1 1 1]);
lighting gouraud;
%view(30,30);
angl = 1;
% rotate around the z-axis
for iTest = 1:360
    rotate(h,origPt,angl,direPt); drawnow;
    pause(0.025);
end

FileName = 'Suppl movie - RS gamma env emb - 3D rotation - 3D shading - dim2-4';
% Create video object
daObj=VideoWriter(FileName,'MPEG-4'); %my preferred format
if isfield(OptionZ,'FrameRate')
    daObj.FrameRate=OptionZ.FrameRate;
end
% open object, preparatory to making the video
open(daObj);

for iRot = 1:360
    rotate(h,origPt,angl,direPt); drawnow;
    pause(0.025);
    writeVideo(daObj,getframe(gcf)); %use figure, since axis changes size based on view
end
% clean up
close(daObj);
%% Suppl - movie of spinning ROIs in dims 3-5
mov2Name = 'Average emb movie dims 3-5';
figure('Name',mov1Name,'Position',[134 10 900 771]);
fontSize = 10;
fontWeight = 'bold';
faceAlpha = 0.15;
plotEmbed(fig3.bootstrapMn(:,3:5),[0,90],fig3.ROIs,fig3.colorMap,fig3.bootstrapSD(:,2:4),...
    {'Dimension 2','Dimension 3','Dimension 4'},fontSize,fontWeight,faceAlpha);

ax = gca;
ax.XLabel.FontSize = 14; ax.XLabel.Rotation = 5;
ax.YLabel.FontSize = 14; ax.YLabel.Rotation = 295;
ax.ZLabel.FontSize = 14;
ax.XGrid = 'on'; %ax.XAxis.Visible = 'off';
ax.YGrid = 'on'; %ax.YAxis.Visible = 'off';
ax.ZGrid = 'on'; %ax.ZAxis.Visible = 'off';
ax.Projection = 'perspective';

startPos = [0.7748,-0.7897];
ax.View = startPos;
ax.CameraViewAngle=-25;
ax.CameraPosition = [0.5,2,0.5];

OptionZ.FrameRate=15;OptionZ.Duration=10;OptionZ.Periodic=true;
h = ax.Children;

origPt = [1,0,0];
direPt = [0,0,0];
light('Position',[1 1 1],'Style','infinit','Color',[1 1 1]);
lighting gouraud;

angl = 1;
% rotate around the z-axis
for iTest = 1:360
    rotate(h,origPt,angl,direPt); drawnow;
    pause(0.025);
end

FileName = 'Suppl movie - RS gamma env emb - 3D rotation - dim3-5';
% Create video object
daObj=VideoWriter(FileName,'MPEG-4'); %my preferred format
if isfield(OptionZ,'FrameRate')
    daObj.FrameRate=OptionZ.FrameRate;
end
% open object, preparatory to making the video
open(daObj);

for iRot = 1:360
    rotate(h,origPt,angl,direPt); drawnow;
    pause(0.025);
    writeVideo(daObj,getframe(gcf)); %use figure, since axis changes size based on view
end
% clean up
close(daObj);

%%

function [h] = plotAvgEmbedding(data,figName)

h = figure('Name',figName,'Position',[138 83 929 900]);
tiledlayout(3,1,'TileSpacing','compact','Padding','none')
nexttile(1);
plotEmbed(data.bootstrapMn(:,2:4),[0,90],data.ROIs,data.colorMap,data.bootstrapSD(:,2:4));
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(2);
plotEmbed(data.bootstrapMn(:,2:4),[0,0],data.ROIs,data.colorMap,data.bootstrapSD(:,2:4));
ax = gca;
ax.XTickLabel = {};
xlabel('');
nexttile(3);
plotEmbed(data.bootstrapMn(:,[2,3,5]),[0,0],data.ROIs,data.colorMap,data.bootstrapSD(:,[2,3,5]),{'dim1','dim2','dim4'});

end

function [h] = plotDendrogram(data,figName,minDim,maxDim,rotateFlag)

if nargin<3
    minDim = 2;
    maxDim = 5;
    rotateFlag = 0;
end
h = figure('Name',figName);

linkMeth = 'ward'; clustThresh = 4.5;
X = data.Emb(:,minDim:maxDim);
Y = pdist(X);
Z = linkage(squareform(Y),linkMeth);
maxVal = max(Z(:,3));
D = pdist(data.Emb(:,minDim:maxDim));
leafOrder = optimalleaforder(Z,D,'Criteria','group');
H = dendrogram(Z,size(data.Emb,1),'Reorder',leafOrder,'Labels',data.ROIs,'ColorThreshold',maxVal/clustThresh);
set(H,'LineWidth',2);
ax = gca;
ax.XTickLabelRotation = 45;
if rotateFlag
    ax.XDir = 'rev';
    ax.CameraUpVector = [-1,0,0];
else
    ax.CameraUpVector = [0,1,0];
end
%clustOut = cluster(Z,'Cutoff',(maxVal/clustThresh),'Criterion','distance');
end

function [h] = plotHubness(data,figName,minDim,maxDim)
if nargin<3
    minDim = 2;
    maxDim = 5;
end
% Calculate 'hubness' as distance from center of data cloud
ctrDist = zeros(1,size(data.Emb,1));
centroid = mean(data.Emb(:,minDim:maxDim),1);
for iRow = 1:size(data.Emb,1)
    ctrDist(iRow) = norm(data.Emb(iRow,minDim:maxDim) - centroid);
end
mnConn = mean(data.Adj);

h = figure('Name',figName);
scatter(ctrDist,mnConn,20,data.colorMap,'filled');
hold on
text(ctrDist,mnConn,data.ROIs);
ax = gca;
ax.YLabel.String = 'mean conn';
ax.XLabel.String = 'distance to ctr';
xctr = mean(ctrDist);
yctr = mean(mnConn);
xsd = std(ctrDist);
ysd = std(mnConn);

C = [xctr yctr] ;  % center
a = xsd ;      % major axis
b = ysd ; % minor axis

th = linspace(0,2*pi) ;
% Ellipse
xe = C(1)+a*cos(th) ;
ye = C(2)+b*sin(th) ;
xe2 = C(1)+2*a*cos(th) ;
ye2 = C(2)+2*b*sin(th) ;
% plot
plot(xe,ye,'b:')
plot(xe2,ye2,'b:')
yScale = max(abs(ax.YLim-yctr));
ylim([yctr-yScale yctr+yScale]);
xScale = max(abs(ax.XLim-xctr));
xlim([xctr-xScale xctr+xScale]);
plot([ax.XLim],[yctr yctr],'k:');
plot([xctr xctr],[ax.YLim],'k:');
axis square
end

function [ctrDist] = calcCtrDist(data,minDim,maxDim)
if nargin<3
    minDim = 2;
    maxDim = 5;
end
% Calculate 'hubness' as distance from center of data cloud
ctrDist = zeros(1,size(data.Emb,1));
centroid = mean(data.Emb(:,minDim:maxDim),1);
for iRow = 1:size(data.Emb,1)
    ctrDist(iRow) = norm(data.Emb(iRow,minDim:maxDim) - centroid);
end

end

function [h] = plotHubness1D(ctrDist,figName,ROIs,colorMap)
h = figure('Name',figName);
hold on
nROIs = length(ROIs);
bands = fieldnames(ctrDist);
bands = flip(bands);
yLim = [0.25, length(bands)/2+0.75];
xLim = [0.25, 2];
vFac = 0.05;
hFac = 0.005;
for iBand = 1:length(bands)
    tempDist = ctrDist.(bands{iBand});
    [sortedDist,sortIndex] = sort(tempDist);
    sortedROIs = ROIs(sortIndex);
    sortedColor = colorMap(sortIndex,:);
    dataTemp = sortedDist/median(sortedDist);
    for iROI = 1:nROIs
        if iROI <= 5 || iROI >= nROIs-4
            t = text(dataTemp(1,iROI)+hFac,iBand/2+vFac,sortedROIs{iROI});
            t.Color = sortedColor(iROI,:);
            t.Rotation = 45;
            t.FontSize = 8;
        end
        p = plot(dataTemp(1,iROI),iBand/2,'o');
        p.Color = sortedColor(iROI,:);
        p.MarkerFaceColor = sortedColor(iROI,:);
        p.MarkerSize = 8;
    end
    plot(xLim,[iBand/2,iBand/2],':k');
end

ax = gca;
ax.YLim = yLim;
ax.XLim = xLim;
ax.YTick = (1:length(bands))/2;
ax.YTickLabel = bands;
ax.FontSize = 14;
ax.XLabel.String = 'Normalized distance from center';
end

function plotEmbed(emb,viewAngle,labels,colorMap,uncertainty,axislabels,fontSize,fontWeight,faceAlpha)
if ~exist('fontSize','var')
    fontSize = 6;
end
if ~exist('fontWeight','var')
    fontWeight = 'normal';
end
if ~exist('faceAlpha','var')
    faceAlpha = 0.1;
end
scalefactor = max(abs(emb),[],'all')*1.15;

if isempty(labels)
    scatter3(emb(:,1),emb(:,2),emb(:,3),20,colorMap,'filled')
else
    ecogutils.scatterText(emb(:,1),emb(:,2),emb(:,3),labels,colorMap,fontSize,fontWeight)
end

if nargin>=5 && ~isempty(uncertainty)
    nROI = size(emb,1);
    for iROI = 1:nROI

        [eX,eY,eZ] = ellipsoid(emb(iROI,1),emb(iROI,2),emb(iROI,3),uncertainty(iROI,1),uncertainty(iROI,2),uncertainty(iROI,3));

        s = surf(eX,eY,eZ,'FaceAlpha',faceAlpha,'EdgeColor','none','FaceColor',colorMap(iROI,:));
    end
end

xlim([-scalefactor scalefactor]);
ylim([-scalefactor scalefactor]);
zlim([-scalefactor scalefactor]);

if nargin>=6
    xlabel(axislabels{1})
    ylabel(axislabels{2})
    zlabel(axislabels{3})
else
    xlabel('dim1')
    ylabel('dim2')
    zlabel('dim3')
end
% set(gca,'Projection','perspective')
axis square

if ~isempty(viewAngle)
    view(viewAngle(1),viewAngle(2));
end

end